@@ -757,9 +757,8 @@ attributes = {
     types=empty_list,
     const=frozenset(['start', 'end', 'inherit', 'middle'])),
 'text-decoration': SVGAttribute('text-decoration', anim=True,
-    types=empty_list,
-    const=frozenset(['', 'overline', 'none', 'underline', 'line-through',
-                     'inherit', 'blink'])),
+    types=frozenset(['list-of-text-decoration-style']),
+    const=frozenset(['', 'none', 'inherit'])),
 'text-rendering': SVGAttribute('text-rendering', anim=True,
     types=empty_list,
     const=frozenset(['auto', 'optimizeSpeed', 'optimizeLegibility',
