@@ -81,6 +81,15 @@ class TestGetCoordinate(unittest.TestCase):
         self.assertTrue(validator.check_svg_type("rgb(10%, 20%, 30%)", 'color'))
         self.assertTrue(validator.check_svg_type("rgb(10.1%, 20.2%, 30.3%)", 'color'))
 
+    def test_text_decoration_styles(self):
+        validator = get_validator('full', debug=True)
+        self.assertTrue(validator.check_svg_type('overline', 'list-of-text-decoration-style'))
+        self.assertTrue(validator.check_svg_type('underline', 'list-of-text-decoration-style'))
+        self.assertTrue(validator.check_svg_type('line-through', 'list-of-text-decoration-style'))
+        self.assertTrue(validator.check_svg_type('blink', 'list-of-text-decoration-style'))
+        self.assertTrue(validator.check_svg_type('underline overline blink', 'list-of-text-decoration-style'))
+        with self.assertRaises(TypeError):
+            validator.check_svg_type('underline overline inherit', 'list-of-text-decoration-style')
 
 
 class TestCheckCoordinate(unittest.TestCase):
@@ -141,5 +150,12 @@ class TestCheckAngle(unittest.TestCase):
         for value in ('10cm', '-10px', '10in', '1gon', '3°'):
             self.assertRaises(TypeError, validator.check_svg_type, value, 'angle')
 
-if __name__=='__main__':
+
+class TestCheckTypes(unittest.TestCase):
+    def test_class_names(self):
+        validator = get_validator('full', debug=True)
+        self.assertTrue(validator.is_valid_svg_type('class1 class2', 'list-of-name'))
+
+
+if __name__ == '__main__':
     unittest.main()
